@@ -18,7 +18,7 @@ import (
 	"time"
 
 	"github.com/ProtonMail/gopenpgp/v2/crypto" // MIT License
-	"github.com/mattn/go-xmpp"                 // BSD-3-Clause
+	"github.com/mattn/go-xmpp"                // BSD-3-Clause
 	"github.com/pborman/getopt/v2"             // BSD-3-Clause
 )
 
@@ -229,6 +229,9 @@ func main() {
 		os.Exit(0)
 	}
 
+	// Check whether an authentification mechanism is pinned.
+	authMech, _ := parsePinFile(user)
+
 	// Set XMPP connection options.
 	options := xmpp.Options{
 		Host:        server,
@@ -246,6 +249,7 @@ func main() {
 		StartTLS:  !*flagDirectTLS,
 		Debug:     *flagDebug,
 		TLSConfig: &tlsConfig,
+		Mechanism: authMech,
 	}
 
 	// Read message from file.
@@ -292,6 +296,14 @@ func main() {
 	if err != nil {
 		log.Fatal(err)
 	}
+	// If no authentification mechanism is pinned and a SCRAM mechanism is
+	// used, write the used mechanism to the pin file.
+	if authMech == "" && strings.HasPrefix(client.Mechanism, "SCRAM") {
+		err = writePinFile(client.Mechanism, user)
+		if err != nil {
+			log.Println("could not write authentification mechanism pin file:", err)
+		}
+	}
 
 	iqc := make(chan xmpp.IQ, defaultBufferSize)
 	msgc := make(chan xmpp.Chat, defaultBufferSize)
